@@ -4,37 +4,40 @@ use strict;
 use warnings;
 
 # ABSTRACT: This module wraps the www.judobase.org website API.
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use HTTP::Request;
 use JSON::Tiny 'decode_json';
-use LWP::UserAgent;
 use Moo;
 
 #extends 'Webservice::Judobase';
 use namespace::clean;
 
+has 'ua' => (
+    is       => 'ro',
+    required => 1,
+);
+
 has 'url' => (
-    is      => 'ro',
-    default => 'http://data.judobase.org/api/',
+    is       => 'ro',
+    required => 1,
 );
 
 sub best_results {
     my ( $self, %args ) = @_;
     return { error => 'id parameter is required' } unless defined $args{id};
 
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.best_results&params[id_person]='
-      . $args{id};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.best_results&params[id_person]='
+        . $args{id};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     return decode_json $response->content
-      if $response->code == 200;
+        if $response->code == 200;
 
     return { error => 'Error retreiving competitor info' };
 }
@@ -43,19 +46,18 @@ sub birthdays_competitors {
     my ( $self, %args ) = @_;
 
     return { error => 'min_age parameter is required' }
-      unless defined $args{min_age};
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.birthday_competitors&params[min_age]='
-      . $args{min_age};
+        unless defined $args{min_age};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.birthday_competitors&params[min_age]='
+        . $args{min_age};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     return decode_json $response->content
-      if $response->code == 200;
+        if $response->code == 200;
 
     return { error => 'Error retreiving competitor info' };
 }
@@ -64,18 +66,17 @@ sub contests {
     my ( $self, %args ) = @_;
 
     return { error => 'id parameter is required' } unless defined $args{id};
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.contests&params[id_person]='
-      . $args{id};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.contests&params[id_person]='
+        . $args{id};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     return decode_json $response->content
-      if $response->code == 200;
+        if $response->code == 200;
 
     return { error => 'Error retreiving competitor info' };
 
@@ -85,18 +86,17 @@ sub contests_statistics {
     my ( $self, %args ) = @_;
 
     return { error => 'id parameter is required' } unless defined $args{id};
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.contests_statistics&params[id_person]='
-      . $args{id};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.contests_statistics&params[id_person]='
+        . $args{id};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     return decode_json $response->content
-      if $response->code == 200;
+        if $response->code == 200;
 
     return { error => 'Error retreiving competitor contests statistics' };
 
@@ -107,15 +107,14 @@ sub fights_statistics {
 
     return { error => 'id parameter is required' } unless defined $args{id};
 
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.fights_statistics&params[id_person]='
-      . $args{id};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.fights_statistics&params[id_person]='
+        . $args{id};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     if ( $response->code == 200 ) {
         my $data = decode_json $response->content;
@@ -132,18 +131,17 @@ sub info {
 
     return { error => 'id parameter is required' } unless defined $args{id};
 
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.info&params[id_person]='
-      . $args{id};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.info&params[id_person]='
+        . $args{id};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     return decode_json $response->content
-      if $response->code == 200;
+        if $response->code == 200;
 
     return { error => 'Error retreiving competitor info' };
 }
@@ -153,15 +151,14 @@ sub wrl_current {
 
     return { error => 'id parameter is required' } unless defined $args{id};
 
-    my $url =
-        $self->url
-      . 'get_json?params[action]=competitor.wrl_current&params[id_person]='
-      . $args{id};
+    my $url
+        = $self->url
+        . '?params[action]=competitor.wrl_current&params[id_person]='
+        . $args{id};
 
-    my $ua = LWP::UserAgent->new;
     my $request = HTTP::Request->new( GET => $url );
 
-    my $response = $ua->request($request);
+    my $response = $self->ua->request($request);
 
     if ( $response->code == 200 ) {
         my $data = decode_json $response->content;
